<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

try {
    // Überprüfung, ob der Benutzer eingeloggt ist und die Rolle „Admin“ hat
    $isAdmin = isset($_SESSION['rolle']) && $_SESSION['rolle'] === 'Admin';

    // Lagerplätze abrufen
    $stmt = $pdo->query('SELECT * FROM lagerplaetze');
    $lagerplaetze = $stmt->fetchAll();

    // Ebenen aus der Datenbank laden
    $stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "lagerplatz_ebenen" LIMIT 1');
    $stmt->execute();
    $ebenenSetting = $stmt->fetch();
    $lagerplatz_ebenen = $ebenenSetting ? json_decode($ebenenSetting['value'], true) : [];

    // Lagerplatz oder Bereich hinzufügen
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['addLagerplatz'])) {
        $prefix = trim($_POST['prefix']);
        $standort = trim($_POST['standort']);
        $beschreibung = trim($_POST['beschreibung']);
        $kapazitaet = (int)$_POST['kapazitaet'];
        $ebene = trim($_POST['ebene']);
        $von = isset($_POST['von']) && $_POST['von'] !== '' ? (int)$_POST['von'] : null;
        $bis = isset($_POST['bis']) && $_POST['bis'] !== '' ? (int)$_POST['bis'] : null;
        $lastInsertedId = null;

        $pdo->beginTransaction();
        if ($von !== null && $bis !== null && $von <= $bis) {
            for ($i = $von; $i <= $bis; $i++) {
                $name = $prefix . '/' . str_pad($i, 2, '0', STR_PAD_LEFT);
                $stmt = $pdo->prepare('INSERT INTO lagerplaetze (name, standort, beschreibung, kapazitaet, belegung, ebene) VALUES (?, ?, ?, ?, 0, ?)');
                $stmt->execute([$name, $standort, $beschreibung, $kapazitaet, $ebene]);
                $lastInsertedId = $pdo->lastInsertId();
            }
        } else {
            $name = $prefix;
            $stmt = $pdo->prepare('INSERT INTO lagerplaetze (name, standort, beschreibung, kapazitaet, belegung, ebene) VALUES (?, ?, ?, ?, 0, ?)');
            $stmt->execute([$name, $standort, $beschreibung, $kapazitaet, $ebene]);
            $lastInsertedId = $pdo->lastInsertId();
        }
        $pdo->commit();

        header('Location: lagerplaetze.php#lagerplatz_' . $lastInsertedId);
        exit();
    }

    // Lagerplatz aktualisieren
    if ($isAdmin && $_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['updateLagerplatz'])) {
        $lagerplatzId = (int)$_POST['lagerplatz_id'];
        $neueBelegung = (int)$_POST['belegung'];
        $neueKapazitaet = (int)$_POST['kapazitaet'];
        $beschreibung = $_POST['beschreibung'];

        if ($neueBelegung > $neueKapazitaet) {
            $neueBelegung = $neueKapazitaet;
        }

        $stmt = $pdo->prepare('UPDATE lagerplaetze SET belegung = ?, kapazitaet = ?, beschreibung = ? WHERE id = ?');
        $stmt->execute([$neueBelegung, $neueKapazitaet, $beschreibung, $lagerplatzId]);

        header('Location: lagerplaetze.php#lagerplatz_' . $lagerplatzId);
        exit();
    }

    // Lagerplatz löschen
    if ($isAdmin && $_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['deleteLagerplatz'])) {
        $lagerplatzId = (int)$_POST['lagerplatz_id'];
        $pdo->beginTransaction();
        try {
            $stmt = $pdo->prepare('DELETE FROM inventur_protokoll WHERE lagerplatz_id = ?');
            $stmt->execute([$lagerplatzId]);

            $stmt = $pdo->prepare('DELETE FROM lagerplaetze WHERE id = ?');
            $stmt->execute([$lagerplatzId]);

            $pdo->commit();
            header('Location: lagerplaetze.php');
            exit();
        } catch (PDOException $e) {
            $pdo->rollBack();
            echo "Fehler beim Löschen des Lagerplatzes: " . $e->getMessage();
        }
    }
} catch (PDOException $e) {
    echo "Datenbankfehler: " . $e->getMessage();
    exit();
}

?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Lagerplätze</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css" rel="stylesheet">
    <!-- Eigenes CSS -->
    <style>
        body {
            background-color: #f8f9fa;
            font-family: 'Roboto', sans-serif;
        }
        /* Navbar Styling */
        .navbar {
            height: 86px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: background-color 0.5s, box-shadow 0.5s;
        }

        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
            height: 66px;
        }

        .navbar-brand img {
            height: 100%; /* Höhe des Logos auf die Höhe der Navbar setzen */
            width: auto; /* Proportionen beibehalten */
            object-fit: contain; /* Falls nötig, das Logo anpassen */
        }
        /* Main Container */
        .container {
            margin: 0 auto; /* Zentriert den Container horizontal */
            padding-top: 40px;
            padding-bottom: 40px;
            max-width: 80%; /* Optional: Breite des Containers beschränken */
            text-align: center; /* Optional: Zentriert den Text */
        }
        /* Cards Styles */
        .lagerplatz-card {
            margin-bottom: 20px;
            display: flex;
            justify-content: center; /* Zentriert die Karte innerhalb ihrer Spalte */
        }
        .lagerplatz-card .card {
            border: none;
            border-radius: 15px;
            overflow: hidden;
            transition: 0.3s;
            background-color: #fff;
            box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
            width: 100%; /* Standardbreite */
            max-width: 400px; /* Maximale Breite für größere Bildschirme */
        }

        .lagerplatz-card .card:hover {
            transform: translateY(-5px);
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
        }
        .lagerplatz-card .card-header {
            background-color: #007bff;
            color: #fff;
            padding: 15px;
            font-size: 1.25rem;
            font-weight: bold;
        }
        .lagerplatz-card .card-body {
            padding: 20px;
        }
        .lagerplatz-card .card-body p {
            margin-bottom: 10px;
        }
        .progress {
            height: 10px;
            border-radius: 5px;
        }
        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
            color: #ff6f61;
        }
        .progress-bar.green {
            background-color: #28a745;
        }
        .progress-bar.yellow {
            background-color: #ffc107;
        }
        .progress-bar.red {
            background-color: #dc3545;
        }
        /* Responsive Styles */
        @media (max-width: 767px) {
    .sidebar {
        display: none;
    }
    .container {
        margin: 0;
        padding: 20px;
    }
    .mobile-menu {
        display: flex;
        justify-content: space-around;
        align-items: center;
        background-color: #212529;
        padding: 10px 0;
        position: fixed;
        bottom: 0;
        left: 0;
        right: 0;
        z-index: 1000;
    }
    .mobile-menu a {
        color: #fff;
        font-size: 18px;
        text-decoration: none;
    }

    /* Cards zentrieren */
    #cardView {
        display: flex;
        flex-direction: column; /* Karten untereinander anordnen */
        align-items: center; /* Karten horizontal zentrieren */
        margin: 0 auto; /* Sicherstellen, dass die Karten zentriert bleiben */
    }
    .lagerplatz-card {
        display: flex;
        justify-content: center; /* Horizontale Zentrierung */
        margin: 15px auto; /* Gleichmäßiger Abstand zwischen Karten */
        width: 100%; /* Volle Breite des Containers */
        max-width: 90%; /* Maximal 90% der Bildschirmbreite */
    }
    .lagerplatz-card .card {
        width: 100%; /* Passt die Kartenbreite an die Bildschirmbreite an */
        max-width: 400px; /* Begrenzung für große Bildschirme */
        margin: 0 auto; /* Sicherstellen, dass die Karte im Container zentriert ist */
    }
}
        /* Search Bar */
        .search-bar .form-control {
            flex: 1;
        }
        .search-bar .btn {
            margin-left: 10px;
        }
        /* Toggle View Button */
        .toggle-view-btn {
            margin-left: auto;
        }
        /* Loading Overlay */
        #loadingOverlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(255, 255, 255, 0.95);
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
            z-index: 9999;
            visibility: visible;
            opacity: 1;
            transition: opacity 0.3s ease, visibility 0.3s ease;
        }

        /* Animation Container */
        .loadingAnimation {
            display: flex;
            justify-content: center;
            gap: 15px;
            margin-bottom: 20px;
        }

        /* Paletten-Animation */
        .pallet {
            width: 60px;
            height: 30px;
            background-color: #007bff;
            border-radius: 4px;
            position: relative;
            animation: pallet-bounce 1.2s infinite ease-in-out;
        }

        .pallet:nth-child(2) {
            animation-delay: 0.2s;
        }

        .pallet:nth-child(3) {
            animation-delay: 0.4s;
        }

        /* Bouncing Animation */
        @keyframes pallet-bounce {
            0%, 80%, 100% {
                transform: translateY(0);
            }
            50% {
                transform: translateY(-20px);
            }
        }

        /* SMP Text Animation */
        .loadingText {
            display: flex;
            justify-content: center;
            align-items: center;
            font-size: 2.5rem;
            font-weight: bold;
            font-family: 'Roboto', sans-serif;
            color: #007bff;
        }

        .letter {
            opacity: 0;
            transform: scale(0.8);
            animation: fade-in 1.5s ease-in-out infinite;
        }

        .letter:nth-child(1) {
            animation-delay: 0s;
        }

        .letter:nth-child(2) {
            animation-delay: 0.2s;
        }

        .letter:nth-child(3) {
            animation-delay: 0.4s;
        }

        @keyframes fade-in {
            0%, 80%, 100% {
                opacity: 0;
                transform: scale(0.8);
            }
            50% {
                opacity: 1;
                transform: scale(1);
            }
        }

        .fixed-header .search-bar {
            display: flex;
            justify-content: center;
            align-items: center;
            gap: 10px;
            margin-bottom: 15px;
        }

        .fixed-header .search-bar input {
            max-width: 400px;
            flex-grow: 1;
        }


        .fixed-header .mb-3 {
    display: flex;
    justify-content: center;
    gap: 20px;
    flex-wrap: wrap;
}
        /* Fixierter Kopfbereich */
        .fixed-header {
            position: sticky;
            top: 0;
            text-align: center;
            background-color: #f8f9fa;
            z-index: 10;
            padding: 20px 0;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        /* Lagerplätze scrollbarer Bereich */
        .scrollable-container {
            max-height: calc(100vh - 200px); /* Verfügbare Höhe basierend auf Header */
            overflow-y: auto;
            padding: 10px;
        }

        #content {
            opacity: 0;
            transition: opacity 0.3s ease;
        }

        #content:not([hidden]) {
            opacity: 1;
        }


        /* List View Styles */
        #listView {
            display: none;
        }
        #listView table {
            background-color: #fff;
            border-collapse: collapse;
        }
        #listView th, #listView td {
            text-align: left;
            padding: 12px;
        }
        #listView th {
            background-color: #007bff;
            color: #fff;
        }
        #listView tr:nth-child(even) {
            background-color: #f2f2f2;
        }
        /* Buttons */
        .btn-outline-primary {
            color: #007bff;
            border-color: #007bff;
        }
        .btn-outline-primary:hover {
            background-color: #007bff;
            color: #fff;
        }
        .btn-outline-danger {
            color: #dc3545;
            border-color: #dc3545;
        }
        .btn-outline-danger:hover {
            background-color: #dc3545;
            color: #fff;
        }

        @media (max-width: 767.98px) {
            
    .mobile-nav {
        display: flex;
        position: fixed;
        bottom: 0;
        left: 0;
        right: 0;
        background-color: #343a40;
        border-top: 1px solid #495057;
        justify-content: space-around;
        padding: 10px 0;
        z-index: 1000;
    }
    .mobile-nav a {
        color: #adb5bd;
        text-decoration: none;
        font-size: 0.85em;
        text-align: center;
        flex: 1;
        display: flex;
        flex-direction: column;
        align-items: center;
    }
    .mobile-nav a i {
        font-size: 1.5em;
        margin-bottom: 2px;
    }
    .mobile-nav a.active {
        color: #ffffff;
    }
}

        /* Verhindert Flackern durch setTimeout */
        canvas {
            opacity: 1;
            transition: opacity 0.5s;
        }
    </style>
</head>
<body>
<div id="loadingOverlay">
    <div class="loadingAnimation">
        <!-- Paletten-Animation -->
        <div class="pallet"></div>
        <div class="pallet"></div>
        <div class="pallet"></div>
    </div>
    <!-- SMP Text -->
    <div class="loadingText">
        <span class="letter">S</span>
        <span class="letter">M</span>
        <span class="letter">P</span>
    </div>
</div>

<div id="content" hidden>
<!-- Navigation für Desktop -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php"><img src="img/logo.png"></a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
                 <i class="bi bi-speedometer2 me-1"></i>Dashboard
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
                 <i class="bi bi-list-task me-1"></i>Aufgaben
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
                 <i class="bi bi-box-seam me-1"></i>Lagerplätze
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="bericht.php">
                 <i class="bi bi-bar-chart-fill me-1"></i>Berichte
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
                 <i class="bi bi-gear-fill"></i>Einstellungen
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="logout.php">
                 <i class="bi bi-box-arrow-right me-1"></i>Abmelden
             </a>
         </li>
       </ul>
    </div>
  </div>
</nav>

<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
        <i class="bi bi-speedometer2"></i>
        Dashboard
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="fixed-header">
    <h2 class="mb-4"><i class="bi bi-box-seam me-2"></i>Lagerplätze</h2>

    <div class="search-bar d-flex align-items-center mb-3">
        <input type="text" id="searchInput" class="form-control me-2" placeholder="Suche nach Lagerplatzname oder Standort..." onkeyup="filterCards()" />
        <button id="resetBtn" class="btn btn-outline-secondary" onclick="resetFilter()">Reset</button>
        <button id="toggleView" class="btn btn-outline-primary ms-3 toggle-view-btn" onclick="toggleView()">Listenansicht</button>
    </div>

    <div class="mb-3">
        <label class="form-label">Platzebenen:</label>
        <?php foreach ($lagerplatz_ebenen as $ebene): ?>
            <div class="form-check form-check-inline">
                <input class="form-check-input" type="checkbox" name="ebene" value="<?php echo htmlspecialchars($ebene['kurzel']); ?>" id="ebene_<?php echo htmlspecialchars($ebene['kurzel']); ?>" checked>
                <label class="form-check-label" for="ebene_<?php echo htmlspecialchars($ebene['kurzel']); ?>">
                    <?php echo htmlspecialchars($ebene['bezeichnung']); ?>
                </label>
            </div>
        <?php endforeach; ?>
    </div>
</div>

<div class="container">
    <?php if ($isAdmin): ?>
        <button type="button" class="btn btn-success mb-3" data-bs-toggle="modal" data-bs-target="#addLagerplatzModal">
            <i class="bi bi-plus-circle me-1"></i>Neuer Lagerplatz oder Bereich
        </button>
    <?php endif; ?>

    <!-- Modal zum Hinzufügen eines Lagerplatzes -->
    <div class="modal fade" id="addLagerplatzModal" tabindex="-1" aria-labelledby="addLagerplatzModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form action="lagerplaetze.php" method="POST">
                    <div class="modal-header">
                        <h5 class="modal-title" id="addLagerplatzModalLabel">Neuen Lagerplatz oder Bereich hinzufügen</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
                    </div>
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="ebene" class="form-label">Ebene auswählen</label>
                            <select class="form-select" id="ebene" name="ebene" required>
                                <option value="" disabled selected>Bitte Ebene auswählen</option>
                                <?php foreach ($lagerplatz_ebenen as $ebene): ?>
                                    <option value="<?php echo htmlspecialchars($ebene['kurzel']); ?>">
                                        <?php echo htmlspecialchars($ebene['bezeichnung']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="prefix" class="form-label">Name des Lagerplatzes (oder Präfix für Bereich, z.B. DG)</label>
                            <input type="text" class="form-control" id="prefix" name="prefix" required>
                        </div>
                        <div class="row">
                            <div class="col">
                                <label for="von" class="form-label">Von (optional)</label>
                                <input type="number" class="form-control" id="von" name="von" min="1" placeholder="z.B. 1">
                            </div>
                            <div class="col">
                                <label for="bis" class="form-label">Bis (optional)</label>
                                <input type="number" class="form-control" id="bis" name="bis" min="1" placeholder="z.B. 10">
                            </div>
                        </div>
                        <div class="mb-3 mt-3">
                            <label for="standort" class="form-label">Standort</label>
                            <input type="text" class="form-control" id="standort" name="standort" required>
                        </div>
                        <div class="mb-3">
                            <label for="beschreibung" class="form-label">Beschreibung</label>
                            <textarea class="form-control" id="beschreibung" name="beschreibung" rows="3"></textarea>
                        </div>
                        <div class="mb-3">
                            <label for="kapazitaet" class="form-label">Kapazität (Anzahl der Europaletten)</label>
                            <input type="number" class="form-control" id="kapazitaet" name="kapazitaet" value="5" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Abbrechen</button>
                        <button type="submit" class="btn btn-success" name="addLagerplatz"><i class="bi bi-save"></i> Hinzufügen</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <!-- Kartenansicht -->
    <div class="row" id="cardView">
    <?php foreach ($lagerplaetze as $lagerplatz):
        $auslastung = ($lagerplatz['kapazitaet'] > 0) ? ($lagerplatz['belegung'] / $lagerplatz['kapazitaet']) * 100 : 0;
        $color = $auslastung > 80 ? 'red' : ($auslastung > 50 ? 'yellow' : 'green');

        // Ebene aus dem Namen extrahieren (erste zwei Buchstaben oder spezifische Logik für "GH")
        $ebene = strtoupper(substr($lagerplatz['name'], 0, 2));
        if (preg_match('/^\d{2}\/\d{2}\/\d{2}$/', $lagerplatz['name'])) {
            $ebene = 'GH'; // Markiere Namen im "14/01/01"-Format als GH
        }
    ?>
        <div class="col-lg-4 col-md-6 col-sm-12 lagerplatz-card" id="lagerplatz_<?php echo $lagerplatz['id']; ?>" 
             data-name="<?php echo htmlspecialchars(strtolower($lagerplatz['name'])); ?>" 
             data-standort="<?php echo htmlspecialchars(strtolower($lagerplatz['standort'])); ?>" 
             data-ebene="<?php echo htmlspecialchars(strtolower($lagerplatz['ebene'])); ?>">
            <div class="card">
                <div class="card-header">
                    <?php echo htmlspecialchars($lagerplatz['name']); ?>
                </div>
                <div class="card-body">
                    <p><i class="bi bi-geo-alt-fill me-1"></i><strong>Standort:</strong> <?php echo htmlspecialchars($lagerplatz['standort']); ?></p>
                    <p><i class="bi bi-info-circle-fill me-1"></i><strong>Beschreibung:</strong> <?php echo htmlspecialchars($lagerplatz['beschreibung']); ?></p>
                    <p><i class="bi bi-diagram-3 me-1"></i><strong>Ebene:</strong> <?php echo htmlspecialchars($lagerplatz['ebene']); ?></p> <!-- Kürzel direkt anzeigen -->
                    <p><i class="bi bi-stack me-1"></i><strong>Kapazität:</strong> <?php echo htmlspecialchars($lagerplatz['kapazitaet']); ?></p>
                    <p><i class="bi bi-boxes me-1"></i><strong>Belegung:</strong> <?php echo htmlspecialchars($lagerplatz['belegung']); ?></p>
                    <div class="progress mb-2">
                        <div class="progress-bar <?php echo $color; ?>" role="progressbar" style="width: <?php echo $auslastung; ?>%;" aria-valuenow="<?php echo $auslastung; ?>" aria-valuemin="0" aria-valuemax="100"></div>
                    </div>
                    <p class="text-muted">Auslastung: <?php echo round($auslastung, 2); ?>%</p>
                    <?php if ($isAdmin): ?>
                        <div class="d-flex justify-content-between mt-3">
                            <button class="btn btn-sm btn-outline-primary" data-bs-toggle="modal" data-bs-target="#editModal_<?php echo $lagerplatz['id']; ?>"><i class="bi bi-pencil-square me-1"></i>Bearbeiten</button>
                            <form action="lagerplaetze.php" method="POST" onsubmit="return confirm('Sind Sie sicher, dass Sie diesen Lagerplatz löschen möchten?');">
                                <input type="hidden" name="lagerplatz_id" value="<?php echo $lagerplatz['id']; ?>">
                                <button type="submit" name="deleteLagerplatz" class="btn btn-sm btn-outline-danger"><i class="bi bi-trash me-1"></i>Löschen</button>
                            </form>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- Bearbeiten Modal -->
        <?php if ($isAdmin): ?>
        <div class="modal fade" id="editModal_<?php echo $lagerplatz['id']; ?>" tabindex="-1" aria-labelledby="editModalLabel_<?php echo $lagerplatz['id']; ?>" aria-hidden="true">
          <div class="modal-dialog">
            <div class="modal-content">
              <form action="lagerplaetze.php" method="POST">
                  <div class="modal-header">
                    <h5 class="modal-title" id="editModalLabel_<?php echo $lagerplatz['id']; ?>">Lagerplatz bearbeiten - <?php echo htmlspecialchars($lagerplatz['name']); ?></h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
                  </div>
                  <div class="modal-body">
                      <input type="hidden" name="lagerplatz_id" value="<?php echo $lagerplatz['id']; ?>">
                      <div class="mb-3">
                          <label>Belegung</label>
                          <input type="number" name="belegung" value="<?php echo htmlspecialchars($lagerplatz['belegung']); ?>" min="0" max="<?php echo htmlspecialchars($lagerplatz['kapazitaet']); ?>" class="form-control" required>
                      </div>
                      <div class="mb-3">
                          <label>Kapazität</label>
                          <input type="number" name="kapazitaet" value="<?php echo htmlspecialchars($lagerplatz['kapazitaet']); ?>" class="form-control" required>
                      </div>
                      <div class="mb-3">
                          <label>Beschreibung</label>
                          <textarea name="beschreibung" class="form-control" rows="3"><?php echo htmlspecialchars($lagerplatz['beschreibung']); ?></textarea>
                      </div>
                  </div>
                  <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Abbrechen</button>
                    <button type="submit" name="updateLagerplatz" class="btn btn-primary"><i class="bi bi-save"></i> Speichern</button>
                  </div>
              </form>
            </div>
          </div>
        </div>
        <?php endif; ?>

    <?php endforeach; ?>
</div>


    <!-- Listenansicht -->
    <div id="listView" class="table-responsive">
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>Name</th>
                    <th>Standort</th>
                    <th>Beschreibung</th>
                    <th>Kapazität</th>
                    <th>Belegung</th>
                    <th>Auslastung</th>
                    <?php if ($isAdmin): ?><th>Aktionen</th><?php endif; ?>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($lagerplaetze as $lagerplatz):
                    $auslastung = ($lagerplatz['kapazitaet'] > 0) ? ($lagerplatz['belegung'] / $lagerplatz['kapazitaet']) * 100 : 0;
                    $color = $auslastung > 80 ? 'red' : ($auslastung > 50 ? 'yellow' : 'green');
                    // Ebene aus dem Namen extrahieren
                    $ebene = strtoupper(substr($lagerplatz['name'], 0, 2));
                ?>
                <tr class="lagerplatz-row" data-ebene="<?php echo htmlspecialchars(strtolower($lagerplatz['ebene'])); ?>">
                    <td><?php echo htmlspecialchars($lagerplatz['name']); ?></td>
                    <td><?php echo htmlspecialchars($lagerplatz['standort']); ?></td>
                    <td><?php echo htmlspecialchars($lagerplatz['beschreibung']); ?></td>
                    <td><?php echo htmlspecialchars($lagerplatz['kapazitaet']); ?></td>
                    <td><?php echo htmlspecialchars($lagerplatz['belegung']); ?></td>
                    <td><?php echo htmlspecialchars($lagerplatz['ebene']); ?></td> <!-- Kürzel anzeigen -->
                    <td>
                        <div class="progress">
                            <div class="progress-bar <?php echo $color; ?>" role="progressbar" style="width: <?php echo $auslastung; ?>%;" aria-valuenow="<?php echo $auslastung; ?>" aria-valuemin="0" aria-valuemax="100"></div>
                        </div>
                        <small><?php echo round($auslastung, 2); ?>%</small>
                    </td>
                    <?php if ($isAdmin): ?>
                    <td>
                        <button class="btn btn-sm btn-outline-primary mb-1" data-bs-toggle="modal" data-bs-target="#editModal_<?php echo $lagerplatz['id']; ?>"><i class="bi bi-pencil-square"></i></button>
                        <form action="lagerplaetze.php" method="POST" class="d-inline" onsubmit="return confirm('Sind Sie sicher, dass Sie diesen Lagerplatz löschen möchten?');">
                            <input type="hidden" name="lagerplatz_id" value="<?php echo $lagerplatz['id']; ?>">
                            <button type="submit" name="deleteLagerplatz" class="btn btn-sm btn-outline-danger"><i class="bi bi-trash"></i></button>
                        </form>
                    </td>
                    <?php endif; ?>
                </tr>


                <!-- Bearbeiten Modal für die Listenansicht -->
                <?php if ($isAdmin): ?>
                <div class="modal fade" id="editModal_<?php echo $lagerplatz['id']; ?>" tabindex="-1" aria-labelledby="editModalLabel_<?php echo $lagerplatz['id']; ?>" aria-hidden="true">
                  <div class="modal-dialog">
                    <div class="modal-content">
                      <form action="lagerplaetze.php" method="POST">
                          <div class="modal-header">
                            <h5 class="modal-title" id="editModalLabel_<?php echo $lagerplatz['id']; ?>">Lagerplatz bearbeiten - <?php echo htmlspecialchars($lagerplatz['name']); ?></h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
                          </div>
                          <div class="modal-body">
                              <input type="hidden" name="lagerplatz_id" value="<?php echo $lagerplatz['id']; ?>">
                              <div class="mb-3">
                                  <label>Belegung</label>
                                  <input type="number" name="belegung" value="<?php echo htmlspecialchars($lagerplatz['belegung']); ?>" min="0" max="<?php echo htmlspecialchars($lagerplatz['kapazitaet']); ?>" class="form-control" required>
                              </div>
                              <div class="mb-3">
                                  <label>Kapazität</label>
                                  <input type="number" name="kapazitaet" value="<?php echo htmlspecialchars($lagerplatz['kapazitaet']); ?>" class="form-control" required>
                              </div>
                              <div class="mb-3">
                                  <label>Beschreibung</label>
                                  <textarea name="beschreibung" class="form-control" rows="3"><?php echo htmlspecialchars($lagerplatz['beschreibung']); ?></textarea>
                              </div>
                          </div>
                          <div class="modal-footer">
                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Abbrechen</button>
                            <button type="submit" name="updateLagerplatz" class="btn btn-primary"><i class="bi bi-save"></i> Speichern</button>
                          </div>
                      </form>
                    </div>
                  </div>
                </div>
                <?php endif; ?>

                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

</div>
</div>
<!-- Bootstrap JS und Abhängigkeiten -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

<!-- JavaScript-Funktionen -->
<script>
function filterCards() {
    const input = document.getElementById('searchInput').value.toLowerCase();
    const cards = document.getElementsByClassName('lagerplatz-card');
    const rows = document.getElementsByClassName('lagerplatz-row');
    const resetBtn = document.getElementById('resetBtn');

    // Alle aktivierten Ebenen sammeln
    const ebeneCheckboxes = document.querySelectorAll('input[name="ebene"]:checked');
    const selectedEbenen = Array.from(ebeneCheckboxes).map(cb => cb.value.toLowerCase());

    // Karten filtern
    for (let i = 0; i < cards.length; i++) {
        const name = cards[i].getAttribute('data-name');
        const standort = cards[i].getAttribute('data-standort');
        const ebene = cards[i].getAttribute('data-ebene');

        const matchesSearch = name.includes(input) || standort.includes(input);
        const matchesEbene = selectedEbenen.includes(ebene);

        if (matchesSearch && matchesEbene) {
            cards[i].style.display = '';
        } else {
            cards[i].style.display = 'none';
        }
    }

    // Tabellenzeilen filtern
    for (let i = 0; i < rows.length; i++) {
        const ebene = rows[i].getAttribute('data-ebene');
        const matchesEbene = selectedEbenen.includes(ebene);

        if (matchesEbene) {
            rows[i].style.display = '';
        } else {
            rows[i].style.display = 'none';
        }
    }

    // Reset-Button anzeigen, wenn Filter aktiv sind
    resetBtn.style.display = (input || selectedEbenen.length < document.querySelectorAll('input[name="ebene"]').length) ? 'inline-block' : 'none';
}





// Event Listener für Checkboxen
document.querySelectorAll('input[name="ebene"]').forEach(function(checkbox) {
    checkbox.addEventListener('change', filterCards);
});


function resetFilter() {
    document.getElementById('searchInput').value = '';
    document.querySelectorAll('input[name="ebene"]').forEach(function(checkbox) {
        checkbox.checked = true;
    });
    filterCards();
}


function toggleView() {
    const cardView = document.getElementById("cardView");
    const listView = document.getElementById("listView");
    const toggleBtn = document.getElementById("toggleView");

    if (cardView.style.display === "none" || cardView.style.display === "") {
        cardView.style.display = "flex";
        listView.style.display = "none";
        toggleBtn.textContent = "Listenansicht";
    } else {
        cardView.style.display = "none";
        listView.style.display = "block";
        toggleBtn.textContent = "Kartenansicht";
    }
}

document.addEventListener("DOMContentLoaded", function() {
    // Checkbox-Zustand aus localStorage wiederherstellen
    const ebeneCheckboxes = document.querySelectorAll('input[name="ebene"]');
    ebeneCheckboxes.forEach(function(checkbox) {
        const savedState = localStorage.getItem(checkbox.id);
        if (savedState !== null) {
            checkbox.checked = savedState === 'true'; // Zustand wiederherstellen
        }
    });

    // Filter anwenden
    filterCards();

    // Event-Listener für das Speichern der Checkbox-Zustände
    ebeneCheckboxes.forEach(function(checkbox) {
        checkbox.addEventListener('change', function() {
            localStorage.setItem(checkbox.id, checkbox.checked); // Zustand speichern
        });
    });
});

</script>
<script>
document.addEventListener("DOMContentLoaded", function () {
    const loadingOverlay = document.getElementById("loadingOverlay");
    const content = document.getElementById("content");

    function hideLoading() {
        loadingOverlay.style.opacity = "0";
        setTimeout(() => {
            loadingOverlay.style.visibility = "hidden";
            content.hidden = false;
        }, 300);
    }

    // Prüfe, ob eine Aktion (Hinzufügen/Löschen) abgeschlossen ist
    const urlParams = new URLSearchParams(window.location.search);
    if (urlParams.has('action_completed')) {
        hideLoading();
    } else {
        hideLoading();
    }
});


</script>
</body>
</html>
