<?php
// Starten Sie die Sitzung, falls nicht bereits gestartet
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// Datenbankverbindung einbinden
include 'db_connect.php';

// Lizenzprüfungsfunktion
function verifyLicenseWithServer($licenseKey) {
    $url = 'https://smp-solution.com/license_api.php?action=verify';

    $postData = [
        'license_key' => $licenseKey
    ];

    $ch = curl_init($url);

    curl_setopt_array($ch, [
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_POST => true,
        CURLOPT_POSTFIELDS => $postData,
        CURLOPT_TIMEOUT => 10,
        CURLOPT_SSL_VERIFYPEER => true,
    ]);

    $result = curl_exec($ch);

    if (curl_errno($ch)) {
        $error_msg = curl_error($ch);
        // Protokollieren Sie die cURL-Fehlermeldung
        file_put_contents('curl_error_log.txt', date('[Y-m-d H:i:s] ') . "cURL Fehler: $error_msg\n", FILE_APPEND);
        curl_close($ch);
        return false;
    }

    $http_status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($http_status !== 200) {
        return false;
    }

    $response = json_decode($result, true);

    if (json_last_error() !== JSON_ERROR_NONE) {
        $jsonError = json_last_error_msg();
        file_put_contents('curl_error_log.txt', date('[Y-m-d H:i:s] ') . "JSON Fehler: $jsonError\n", FILE_APPEND);
        return false;
    }

    return $response;
}

// Lizenzprüfung durchführen (Cache-System)
if (!isset($_SESSION['license_cache'])) {
    $_SESSION['license_cache'] = [
        'license_data' => null,
        'last_check' => null
    ];
}

$cacheLifetime = 86400; // 24 Stunden in Sekunden
$currentTime = time();
$licenseResponse = false;

// Lizenzprüfung nur durchführen, wenn Cache abgelaufen ist
if (!isset($_SESSION['license_cache']['last_check']) || ($currentTime - $_SESSION['license_cache']['last_check']) > $cacheLifetime) {
    // Lizenzschlüssel aus der Datenbank abrufen
    $stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "license_key"');
    $stmt->execute();
    $licenseKey = $stmt->fetchColumn();

    if ($licenseKey) {
        $licenseResponse = verifyLicenseWithServer($licenseKey);

        if ($licenseResponse && $licenseResponse['status'] === 'valid') {
            // Lizenzdaten und Zeitstempel in den Session-Cache speichern
            $_SESSION['license_cache'] = [
                'license_data' => $licenseResponse['data'],
                'last_check' => $currentTime
            ];

            // Lizenzdaten in der Datenbank aktualisieren
            $stmt = $pdo->prepare('REPLACE INTO settings (key_name, value) VALUES ("license_data", ?)');
            $stmt->execute([json_encode($licenseResponse['data'])]);
        } else {
            $_SESSION['license_cache'] = [
                'license_data' => null,
                'last_check' => $currentTime
            ];
        }
    }
} else {
    // Lizenzdaten aus dem Cache abrufen
    $licenseResponse = [
        'status' => 'valid',
        'data' => $_SESSION['license_cache']['license_data']
    ];
}

// Überprüfung der Lizenz
if (!$licenseResponse || $licenseResponse['status'] !== 'valid') {
    // Lizenz ist nicht gültig, Lizenzformular anzeigen
    ?>
    <!DOCTYPE html>
    <html lang="de">
    <head>
        <meta charset="UTF-8">
        <title>Lizenzprüfung</title>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
        <style>
            body {
                background-color: #f9f9f9;
                font-family: Arial, sans-serif;
            }
            .container {
                margin-top: 50px;
            }
            .shop-alert {
                margin-top: 20px;
                background-color: #e8f4ff;
                border: 1px solid #007bff;
                color: #007bff;
                padding: 20px;
                border-radius: 8px;
                text-align: center;
            }
            .shop-alert a {
                color: #0056b3;
                text-decoration: none;
                font-weight: bold;
            }
            .shop-alert a:hover {
                text-decoration: underline;
            }
        </style>
    </head>
    <body>
        <div class="container">
            <h2 class="text-center">Lizenzprüfung</h2>

            <!-- Fehlermeldung oder Status anzeigen -->
            <div class="alert alert-danger">Lizenzprüfung fehlgeschlagen oder Lizenz ist ungültig.</div>

            <!-- Lizenzformular -->
            <form method="POST">
                <div class="mb-3">
                    <label for="license_key" class="form-label">Lizenzschlüssel</label>
                    <input type="text" name="license_key" id="license_key" class="form-control" required>
                </div>
                <button type="submit" class="btn btn-primary w-100">Lizenz prüfen</button>
            </form>

            <!-- Hinweis auf den Shop -->
            <div class="shop-alert">
                <p>Sie haben noch keine Lizenz? Besuchen Sie unseren <a href="https://smp-solution.com/shop.php" target="_blank">Lizenz-Shop</a>, um eine passende Lizenz zu erwerben.</p>
            </div>
        </div>

        <!-- Bootstrap JS -->
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    </body>
    </html>
    <?php
    exit;
}
