<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

// Überprüfung, ob der Benutzer angemeldet ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Aktuelle Version aus der Datenbank abrufen
$currentVersion = 'Unbekannt';
try {
    $stmt = $pdo->prepare("SELECT value FROM settings WHERE key_name = 'version'");
    $stmt->execute();
    $currentVersion = $stmt->fetchColumn() ?: 'Unbekannt';
} catch (PDOException $e) {
    $message = "Fehler beim Abrufen der aktuellen Version: " . $e->getMessage();
}

// Nachricht für das Ergebnis des Updates
$message = "";
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['update_zip'])) {
    $file = $_FILES['update_zip'];
    $uploadDir = __DIR__;
    $filePath = $uploadDir . '/' . $file['name'];

    if (move_uploaded_file($file['tmp_name'], $filePath)) {
        $zip = new ZipArchive;
        if ($zip->open($filePath) === TRUE) {
            $zip->extractTo($uploadDir);
            $zip->close();

            // Lesen der Version aus der entpackten JSON-Datei
            $versionFilePath = $uploadDir . '/update_info.json';
            if (file_exists($versionFilePath)) {
                $versionData = json_decode(file_get_contents($versionFilePath), true);
                if (isset($versionData['version'])) {
                    $newVersion = $versionData['version'];

                    // Version in die Datenbank aktualisieren
                    try {
                        $stmt = $pdo->prepare("SELECT COUNT(*) FROM settings WHERE key_name = 'version'");
                        $stmt->execute();
                        $exists = $stmt->fetchColumn();

                        if ($exists) {
                            $stmt = $pdo->prepare("UPDATE settings SET value = :version, updated_at = NOW() WHERE key_name = 'version'");
                        } else {
                            $stmt = $pdo->prepare("INSERT INTO settings (key_name, value, description, created_at, updated_at)
                                VALUES ('version', :version, 'Aktuelle SMP-Softwareversion', NOW(), NOW())");
                        }
                        $stmt->execute([':version' => $newVersion]);
                        $currentVersion = $newVersion;
                        $message = "Update erfolgreich abgeschlossen! Neue Version: $newVersion.";
                    } catch (PDOException $e) {
                        $message = "Datenbankfehler: " . $e->getMessage();
                    }
                } else {
                    $message = "Fehler: version.json enthält keine gültige Versionsnummer.";
                }
            } else {
                $message = "Fehler: version.json konnte nicht gefunden werden.";
            }
        } else {
            $message = "Fehler: ZIP-Datei konnte nicht entpackt werden.";
        }

        // Entfernen der hochgeladenen ZIP-Datei
        unlink($filePath);
    } else {
        $message = "Fehler beim Hochladen der Datei.";
    }
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Update - SMP System</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">
    <style>
        body {
            background-color: #f8f9fa;
            font-family: 'Roboto', sans-serif;
            height: 100%;
        }
        .navbar {
            background-color: #343a40;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }
        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
        }
        .card {
            border-radius: 12px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            border: none;
        }
        .card-header {
            background-color: #007bff;
            color: white;
            font-weight: bold;
            text-align: center;
        }
        .btn-primary {
            background-color: #007bff;
            border: none;
            border-radius: 25px;
            padding: 10px 20px;
            font-size: 1rem;
            transition: background-color 0.3s ease;
        }
        .btn-primary:hover {
            background-color: #0056b3;
        }
        .info-box {
            background-color: #e9f7fe;
            border: 1px solid #007bff;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 20px;
            text-align: center;
        }
        .info-box a {
            text-decoration: none;
            color: #007bff;
            font-weight: bold;
        }
        .info-box a:hover {
            text-decoration: underline;
        }
        .form-control {
            border-radius: 12px;
        }
        footer {
            margin-top: 50px;
            text-align: center;
            color: #6c757d;
        }
    </style>
</head>
<body>
<!-- Navigation -->
<nav class="navbar navbar-expand-lg navbar-dark">
    <div class="container-fluid">
        <a class="navbar-brand" href="index.php"><i class="bi bi-box-seam"></i> SMP System</a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Navigation umschalten">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ms-auto">
                <li class="nav-item"><a class="nav-link" href="dashboard.php"><i class="bi bi-speedometer2"></i> Dashboard</a></li>
                <li class="nav-item"><a class="nav-link" href="lagerplaetze.php"><i class="bi bi-box"></i> Lagerplätze</a></li>
                <li class="nav-item"><a class="nav-link" href="settings.php"><i class="bi bi-gear"></i> Einstellungen</a></li>
                <li class="nav-item"><a class="nav-link" href="logout.php"><i class="bi bi-box-arrow-right"></i> Abmelden</a></li>
            </ul>
        </div>
    </div>
</nav>

<!-- Hauptinhalt -->
<div class="container mt-5">
    <div class="row justify-content-center">
        <!-- Info-Box -->
        <div class="col-md-8">
            <div class="info-box">
                <p>Benötigen Sie ein Update oder weitere Ressourcen? Besuchen Sie unseren <a href="https://smp-solution.com/download.php">Downloadbereich</a>, um die neueste Version herunterzuladen.</p>
            </div>
        </div>
        <!-- Update Card -->
        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <i class="bi bi-arrow-up-circle"></i> SMP System aktualisieren
                </div>
                <div class="card-body">
                    <?php if (!empty($message)): ?>
                        <div class="alert alert-info text-center"><?php echo htmlspecialchars($message); ?></div>
                    <?php endif; ?>
                    <p class="text-center mb-4"><strong>Aktuelle Version:</strong> <?php echo htmlspecialchars($currentVersion); ?></p>
                    <form method="POST" enctype="multipart/form-data">
                        <div class="mb-3">
                            <label for="update_zip" class="form-label">ZIP-Datei hochladen</label>
                            <input type="file" class="form-control" id="update_zip" name="update_zip" required>
                        </div>
                        <button type="submit" class="btn btn-primary w-100">Update durchführen</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Footer -->
<footer>
    <p>&copy; 2024 SMP System. Alle Rechte vorbehalten.</p>
</footer>

<!-- Bootstrap JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
